/*
 * Tapestry Web Application Framework
 * Copyright (c) 2000, 2001 by Howard Ship and Primix
 *
 * Primix
 * 311 Arsenal Street
 * Watertown, MA 02472
 * http://www.primix.com
 * mailto:hship@primix.com
 * 
 * This library is free software.
 * 
 * You may redistribute it and/or modify it under the terms of the GNU
 * Lesser General Public License as published by the Free Software Foundation.
 *
 * Version 2.1 of the license should be included with this distribution in
 * the file LICENSE, as well as License.html. If the license is not
 * included with this distribution, you may find a copy at the FSF web
 * site at 'www.gnu.org' or 'www.fsf.org', or you may write to the
 * Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139 USA.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 */

package com.primix.vlib.ejb.impl;

import javax.ejb.*;
import java.rmi.*;
import javax.jms.*;
import com.primix.tapestry.util.ejb.*;
import javax.naming.*;

/**
 *  Abstract base class for implementing message driven beans.
 *
 *  @author Howard Ship
 *  @version $Id: AbstractMessageDrivenBean.java,v 1.3 2001/06/22 20:40:09 hship Exp $
 */


public abstract class AbstractMessageDrivenBean
	implements MessageDrivenBean, MessageListener
{
	private MessageDrivenContext context;

	/**
	 *  Set by {@link #ejbCreate()}, this contains
	 *  the <code>java:comp/env</code> context.
	 *
	 */
	
	protected Context environment;
	
	public void setMessageDrivenContext(MessageDrivenContext value)
		throws EJBException
	{
		context = value;
	}
	
	
	/**
	 *  Sets up the {@link #environment} instance variable.
	 *
	 */
	
	public void ejbCreate()
		throws EJBException

	{
		try
		{
			Context initial = new InitialContext();
			environment = (Context)initial.lookup("java:comp/env");
		}
		catch (NamingException ex)
		{
			throw new XEJBException("Could not lookup environment.", ex);
		}
	}
	
	/**
	 *   Clears the {@link MessageDrivenContext} attribute.
	 *
	 */
	
	public void ejbRemove()
		throws EJBException
	{
		context = null;
	}
}

