/*
 * Tapestry Web Application Framework
 * Copyright (c) 2000, 2001 by Howard Ship and Primix
 *
 * Primix
 * 311 Arsenal Street
 * Watertown, MA 02472
 * http://www.primix.com
 * mailto:hship@primix.com
 * 
 * This library is free software.
 * 
 * You may redistribute it and/or modify it under the terms of the GNU
 * Lesser General Public License as published by the Free Software Foundation.
 *
 * Version 2.1 of the license should be included with this distribution in
 * the file LICENSE, as well as License.html. If the license is not
 * included with this distribution, you may find a copy at the FSF web
 * site at 'www.gnu.org' or 'www.fsf.org', or you may write to the
 * Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139 USA.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 */

package com.primix.tapestry.form;

import com.primix.tapestry.*;

/**
 *  Implementation of {@link IPropertySelectionRenderer} that
 *  produces a &lt;select&gt; element (containing &lt;option&gt; elements).
 *
 *  @version $Id: SelectPropertySelectionRenderer.java,v 1.8 2001/05/21 22:38:42 hship Exp $
 *  @author Howard Ship
 *
 */

public class SelectPropertySelectionRenderer
implements IPropertySelectionRenderer
{
	/**
	 *  Writes the &lt;select&gt; element.  If the
	 *  {@link PropertySelection} is {@link PropertySelection#isDisabled() disabled}
	 *  then a <code>disabled</code> attribute is written into the tag
	 *  (though Navigator will ignore this).
	 *
	 */

	public void beginRender(PropertySelection component, IResponseWriter writer, 
		IRequestCycle cycle)
	throws RequestCycleException
	{
		writer.begin("select");
		writer.attribute("name", component.getName());

		if (component.isDisabled())
			writer.attribute("disabled");
		
		writer.println();	
	}

	/**
	 *  Closes the &lt;select&gt; element.
	 *
	 */

	public void endRender(PropertySelection component, IResponseWriter writer, IRequestCycle cycle)
	throws RequestCycleException
	{
		writer.end(); // <select>
	}

	/**
	 *  Writes an &lt;option&gt; element.
	 *
	 */

	public void renderOption(PropertySelection component, IResponseWriter writer, IRequestCycle cycle,
		IPropertySelectionModel model, Object option, int index, boolean selected)
	throws RequestCycleException
	{
		writer.beginEmpty("option");
		writer.attribute("value", model.getValue(index));

		if (selected)
			writer.attribute("selected");

		writer.print(model.getLabel(index));
		
		writer.println();	
	}
}
