/*
 * Tapestry Web Application Framework
 * Copyright (c) 2000, 2001 by Howard Ship and Primix
 *
 * Primix
 * 311 Arsenal Street
 * Watertown, MA 02472
 * http://www.primix.com
 * mailto:hship@primix.com
 * 
 * This library is free software.
 * 
 * You may redistribute it and/or modify it under the terms of the GNU
 * Lesser General Public License as published by the Free Software Foundation.
 *
 * Version 2.1 of the license should be included with this distribution in
 * the file LICENSE, as well as License.html. If the license is not
 * included with this distribution, you may find a copy at the FSF web
 * site at 'www.gnu.org' or 'www.fsf.org', or you may write to the
 * Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139 USA.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 */

package com.primix.tapestry.util.io;

import java.util.*;
import java.io.*;

/**
 *  Squeezes a {@link Float}.
 *
 *  @author Howard Ship
 *  @version $Id: FloatAdaptor.java,v 1.4 2001/05/02 14:15:17 hship Exp $
 *
 */

class FloatAdaptor
implements ISqueezeAdaptor
{
    private static final String PREFIX = "f";

    /**
     *  Registers using the prefix 'f'.
     *
     */

    public void register(DataSqueezer squeezer)
    {
        squeezer.register(PREFIX, Float.class, this);
    }

    /**
     *  Invoked <code>toString()</code> on data (which is type {@link Float}),
     *  and prefixs the result.
     *
     */

    public String squeeze(DataSqueezer squeezer, Object data)
    {
        return PREFIX + data.toString();
    }

    /**
     *  Constructs a {@link Float} from the string, after stripping
     *  the prefix.
     *
     */

    public Object unsqueeze(DataSqueezer squeezer, String string)
    {
        return new Float(string.substring(1));
    }

}